@@ -44,19 +44,17 @@
 #include "../objects/polygon_imp.h"
 #include "../objects/text_imp.h"
 
-#include <math.h>
+#include <config-kig.h>
+
+#include <cmath>
 #include <algorithm>
 
-#include <qcheckbox.h>
-#include <qcolor.h>
-#include <qfile.h>
-#include <qtextstream.h>
+#include <QFile>
+#include <QTextStream>
 
-#include <kmessagebox.h>
-
-#include <config-kig.h>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KMessageBox>
+#include <KSharedConfig>
 
 #ifdef HAVE_TRUNC
 #define KDE_TRUNC(a)    trunc(a)
@@ -537,7 +535,7 @@ void PSTricksExportImpVisitor::visit(const RationalBezierImp* imp)
 void LatexExporter::run( const KigPart& doc, KigWidget& w )
 {
     KigFileDialog* kfd = new KigFileDialog(
-        QString(), i18n( "*.tex|Latex Documents (*.tex)" ),
+        QStandardPaths::writableLocation( QStandardPaths::DocumentsLocation ), i18n( "*.tex|Latex Documents (*.tex)" ),
         i18n( "Export as Latex" ), &w );
     kfd->setOptionCaption( i18n( "Latex Options" ) );
     LatexExporterOptions* opts = new LatexExporterOptions( 0L );
