@@ -20,13 +20,11 @@
 */
 
 #include "edittype.h"
-#include "edittype.moc"
 
 #include "ui_edittypewidget.h"
 
 #include <kicondialog.h>
 #include <klineedit.h>
-#include <klocale.h>
 #include <kmessagebox.h>
 #include <KHelpClient>
 #include <QDialogButtonBox>
